@@ -79,7 +79,6 @@ def run_blind_test(
     threshold: float = 0.5,
     save: bool = False,
     save_path: str = None,
-    encoding: str = "UTF-8",
 ) -> pd.DataFrame:
     """Runs a blind test on the given assistant.
 
@@ -97,7 +96,6 @@ def run_blind_test(
         workspace_id (str): The workspace ID for the assistant.
         save (bool, optional): Whether to save the test results. Defaults to False.
         save_path (str, optional): The path to save the test results. Defaults to None.
-        encoding (str, optional): The encoding of the test file. Defaults to "UTF-8".
 
     Returns:
         pd.DataFrame: A DataFrame containing the results of the blind test.
@@ -106,52 +104,53 @@ def run_blind_test(
     results = []
 
     print(f"=== {category} BLIND TEST STARTING ===")
-    with open(path, "r") as f:
-        df = pd.read_csv(f, encoding=encoding)
-        for i in trange(len(df)):
 
-            # Get original text and predicted intent
-            text = df["text"][i]
-            prediction = df["intent"][i].strip()
+    df = pd.read_csv(path)
 
-            # Get the response from the assistant
-            response = assistant.message(
-                workspace_id, input={"text": text}, alternate_intents=True
-            ).get_result()
+    for i in trange(len(df)):
 
-            # If the response is empty, print a message and continue
-            if response is None:
-                print(f"Response is empty for text: {text}")
-                continue
-            elif isinstance(response, dict):
-                intents = response.get("intents", None)
-            else:
-                intents = response.json().get("intents", None)
+        # Get original text and predicted intent
+        text = df["text"][i]
+        prediction = df["intent"][i].strip()
 
-            if intents is None:
-                print(f"Intents is empty for text: {text}")
-                continue
+        # Get the response from the assistant
+        response = assistant.message(
+            workspace_id, input={"text": text}, alternate_intents=True
+        ).get_result()
 
-            # Unpack response
-            intent1 = intents[0]["intent"]
-            intent2 = intents[1]["intent"]
-            intent3 = intents[2]["intent"]
-            confidence1 = intents[0]["confidence"]
-            confidence2 = intents[1]["confidence"]
-            confidence3 = intents[2]["confidence"]
+        # If the response is empty, print a message and continue
+        if response is None:
+            print(f"Response is empty for text: {text}")
+            continue
+        elif isinstance(response, dict):
+            intents = response.get("intents", None)
+        else:
+            intents = response.json().get("intents", None)
 
-            results.append(
-                {
-                    "original_text": text,
-                    "predicted_intent": prediction,
-                    "actual_intent1": intent1.strip(),
-                    "actual_confidence1": confidence1,
-                    "actual_intent2": intent2.strip(),
-                    "actual_confidence2": confidence2,
-                    "actual_intent3": intent3.strip(),
-                    "actual_confidence3": confidence3,
-                }
-            )
+        if intents is None:
+            print(f"Intents is empty for text: {text}")
+            continue
+
+        # Unpack response
+        intent1 = intents[0]["intent"]
+        intent2 = intents[1]["intent"]
+        intent3 = intents[2]["intent"]
+        confidence1 = intents[0]["confidence"]
+        confidence2 = intents[1]["confidence"]
+        confidence3 = intents[2]["confidence"]
+
+        results.append(
+            {
+                "original_text": text,
+                "predicted_intent": prediction,
+                "actual_intent1": intent1.strip(),
+                "actual_confidence1": confidence1,
+                "actual_intent2": intent2.strip(),
+                "actual_confidence2": confidence2,
+                "actual_intent3": intent3.strip(),
+                "actual_confidence3": confidence3,
+            }
+        )
 
     print(f"=== {category} BLIND TEST FINISHED ===")
 
